==> haskell-streaming-commons-0.2.1.1-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-streaming-commons.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: streaming-commons
version: 0.2.1.1
id: streaming-commons-0.2.1.1-8vrO993osU6EG9wXe6jaVA
key: streaming-commons-0.2.1.1-8vrO993osU6EG9wXe6jaVA
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman, Emanuel Borsboom
homepage: https://github.com/fpco/streaming-commons
synopsis: Common lower-level functions needed by various streaming data libraries
description:
    Provides low-dependency functionality commonly needed by various streaming data libraries, such as conduit and pipes.
category: Data
abi: d22481ec252f5c67e9c8bda6a95ff70d
exposed: True
exposed-modules:
    Data.Streaming.ByteString.Builder
    Data.Streaming.ByteString.Builder.Buffer Data.Streaming.FileRead
    Data.Streaming.Filesystem Data.Streaming.Network
    Data.Streaming.Network.Internal Data.Streaming.Process
    Data.Streaming.Process.Internal Data.Streaming.Text
    Data.Streaming.Zlib Data.Streaming.Zlib.Lowlevel
hidden-modules: Data.Text.Internal.Unsafe.Char
                Data.Text.Internal.Unsafe.Shift Data.Text.Internal.Encoding.Utf8
                Data.Text.Internal.Encoding.Utf16 Data.Text.Internal.Encoding.Utf32
import-dirs: /usr/lib/ghc-8.6.5/site-local/streaming-commons-0.2.1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/streaming-commons-0.2.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/streaming-commons-0.2.1.1
hs-libraries: HSstreaming-commons-0.2.1.1-8vrO993osU6EG9wXe6jaVA
depends:
    array-0.5.3.0 async-2.2.2-5KbUJa8fnnu9oaTmXcEjsG base-4.12.0.0
    bytestring-0.10.8.2 directory-1.3.3.0
    network-2.8.0.0-KwUidTBebCCJ8Fjkxwovi process-1.6.5.0
    random-1.1-3ypV4EIycgb35PKjTYYr5q stm-2.5.0.0 text-1.2.3.1
    transformers-0.5.6.2 unix-2.7.2.2 zlib-0.6.2-3orZ4PtYssfHtZIGrJhHYA
haddock-interfaces: /usr/share/doc/haskell-streaming-commons/html/streaming-commons.haddock
haddock-html: /usr/share/doc/haskell-streaming-commons/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-streaming-commons-0.2.1.1-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-streaming-commons.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: streaming-commons
version: 0.2.1.1
id: streaming-commons-0.2.1.1-Cz1nN7Sucqo90QnDfH7On0
key: streaming-commons-0.2.1.1-Cz1nN7Sucqo90QnDfH7On0
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman, Emanuel Borsboom
homepage: https://github.com/fpco/streaming-commons
synopsis: Common lower-level functions needed by various streaming data libraries
description:
    Provides low-dependency functionality commonly needed by various streaming data libraries, such as conduit and pipes.
category: Data
abi: b8429a61de55a4817f9a6b3c87753897
exposed: True
exposed-modules:
    Data.Streaming.ByteString.Builder
    Data.Streaming.ByteString.Builder.Buffer Data.Streaming.FileRead
    Data.Streaming.Filesystem Data.Streaming.Network
    Data.Streaming.Network.Internal Data.Streaming.Process
    Data.Streaming.Process.Internal Data.Streaming.Text
    Data.Streaming.Zlib Data.Streaming.Zlib.Lowlevel
hidden-modules: Data.Text.Internal.Unsafe.Char
                Data.Text.Internal.Unsafe.Shift Data.Text.Internal.Encoding.Utf8
                Data.Text.Internal.Encoding.Utf16 Data.Text.Internal.Encoding.Utf32
import-dirs: /usr/lib/ghc-8.6.5/site-local/streaming-commons-0.2.1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/streaming-commons-0.2.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/streaming-commons-0.2.1.1
hs-libraries: HSstreaming-commons-0.2.1.1-Cz1nN7Sucqo90QnDfH7On0
depends:
    array-0.5.3.0 async-2.2.2-5KbUJa8fnnu9oaTmXcEjsG base-4.12.0.0
    bytestring-0.10.8.2 directory-1.3.3.0
    network-2.8.0.0-FZwMvc7MoUJBpGGHu2O13h process-1.6.5.0
    random-1.1-3ypV4EIycgb35PKjTYYr5q stm-2.5.0.0 text-1.2.3.1
    transformers-0.5.6.2 unix-2.7.2.2 zlib-0.6.2-3orZ4PtYssfHtZIGrJhHYA
haddock-interfaces: /usr/share/doc/haskell-streaming-commons/html/streaming-commons.haddock
haddock-html: /usr/share/doc/haskell-streaming-commons/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
